Fatigue tools
===========================

``wetb`` includes functions to help with the calculation of fatigue
equivalent loads for turbines. The documentation is in a Jupyter
notebook format. You can download the source notebook from the
``wetb`` repository, under ``docs/source/fatigue_tools``.

.. toctree::
    :caption: Fatigue tools
    :maxdepth: 2

    fatigue_nb